// -*- c++ -*-
//  Generated by gtkmmproc from ./../dial.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DIAL_H
#define _GNOMEMM_DIAL_H

/* $Id: dial.gen_h,v 1.5 2000/05/07 04:59:59 kenelson Exp $ */


/* gtkdial.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/widget.h>
#include <libgnomeui/gtkdial.h>

namespace Gtk {
class Dial;
class Dial_Class;
}
namespace Gtk { Gtk::Dial *wrap (GtkDial *o); }
namespace Gtk
{
class Dial : public Widget
{

public:
  typedef Dial          CppObjectType;
  typedef Dial_Class    CppClassType;
  typedef GtkDial           BaseObjectType;
  typedef GtkDialClass      BaseClassType;

private:
  friend class Dial_Class;
  static CppClassType dial_class;

  Dial(const Dial&);
  Dial& operator=(const Dial&); // not implemented

protected:
  void   initialize_class();
  explicit Dial(GtkDial *castitem);

public:
  static GtkType get_type();
  GtkDial* gtkobj()             { return (GtkDial*)(gtkobject); }
  const GtkDial* gtkobj() const { return (GtkDial*)(gtkobject); }
  static bool isA(Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~Dial();

private:

public:
  Dial();




  Gtk::Adjustment* get_adjustment() const;


  void set_update_policy(GtkUpdateType policy);

  // gtk+ does not creat one for you on this interface

  void set_adjustment(Gtk::Adjustment& adjustment);


  gfloat set_percentage(gfloat percent);


  gfloat get_percentage();


  gfloat set_value(gfloat value);


  gfloat get_value();


  void set_view_only(bool view_only=true);

public:

protected:
  // impl functions

};



}


#endif
