// -*- c++ -*-
//  Generated by gtkmmproc from ./../less.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_LESS_H
#define _GNOMEMM_LESS_H

/* $Id: less.gen_h,v 1.5 2000/08/29 18:09:02 kenelson Exp $ */


/* less.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/box.h>
#include <libgnomeui/gnome-less.h>

namespace Gnome {
class Less;
class Less_Class;
}
namespace Gtk { Gnome::Less *wrap (GnomeLess *o); }
namespace Gnome
{
class Less : public Gtk::VBox
{

public:
  typedef Less          CppObjectType;
  typedef Less_Class    CppClassType;
  typedef GnomeLess           BaseObjectType;
  typedef GnomeLessClass      BaseClassType;

private:
  friend class Less_Class;
  static CppClassType less_class;

  Less(const Less&);
  Less& operator=(const Less&); // not implemented

protected:
  void   initialize_class();
  explicit Less(GnomeLess *castitem);

public:
  static GtkType get_type();
  GnomeLess* gtkobj()             { return (GnomeLess*)(gtkobject); }
  const GnomeLess* gtkobj() const { return (GnomeLess*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~Less();

private:

public:
  Less();




  void clear();


  gboolean show_file(const Gtk::string& path);


  gboolean show_command(const Gtk::string& command_line);


  void show_string(const Gtk::string& s);


  gboolean show_filestream(FILE* f);


  gboolean show_fd(int file_descriptor);


  gboolean write_file(const Gtk::string& path);


  gboolean write_fd(int fd);


  void set_fixed_font(bool fixed);


  void reshow();


  void fixed_font();

  void set_font (const Gdk_Font &font);

public:

protected:
  // impl functions

};



}


#endif
