// -*- c++ -*-
//  Generated by gtkmmproc from ./../mdi-generic-child.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_MDI_GENERIC_CHILD_H
#define _GNOMEMM_MDI_GENERIC_CHILD_H

// -*- Mode: C++; style: bsd -*-
/* $Id: mdi-generic-child.gen_h,v 1.5 2001/04/24 14:39:35 murrayc Exp $ */


/* mdi-generic-child.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/mdi-child.h>
#include <libgnomeui/gnome-mdi-generic-child.h>

namespace Gnome {
class MDIGenericChild;
class MDIGenericChild_Class;
}
namespace Gtk { Gnome::MDIGenericChild *wrap (GnomeMDIGenericChild *o); }
namespace Gnome
{
class MDIGenericChild : public MDIChild
{

public:
  typedef MDIGenericChild          CppObjectType;
  typedef MDIGenericChild_Class    CppClassType;
  typedef GnomeMDIGenericChild           BaseObjectType;
  typedef GnomeMDIGenericChildClass      BaseClassType;

private:
  friend class MDIGenericChild_Class;
  static CppClassType mdi_generic_child_class;

  MDIGenericChild(const MDIGenericChild&);
  MDIGenericChild& operator=(const MDIGenericChild&); // not implemented

protected:
  void   initialize_class();
  explicit MDIGenericChild(GnomeMDIGenericChild *castitem);

public:
  static GtkType get_type();
  GnomeMDIGenericChild* gtkobj()             { return (GnomeMDIGenericChild*)(gtkobject); }
  const GnomeMDIGenericChild* gtkobj() const { return (GnomeMDIGenericChild*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~MDIGenericChild();

private:

public:



  MDIGenericChild(const Gtk::string &name);



  void set_view_creator(GnomeMDIChildViewCreator func,gpointer data);

  void set_view_creator_full(GnomeMDIChildViewCreator func,GtkCallbackMarshal marshal,gpointer data,GtkDestroyNotify notify);





  void set_menu_creator(GnomeMDIChildMenuCreator func,gpointer data);

  void set_menu_creator_full(GnomeMDIChildMenuCreator func,GtkCallbackMarshal marshal,gpointer data,GtkDestroyNotify notify);





  void set_config_func(GnomeMDIChildConfigFunc func,gpointer data);

  void set_config_func_full(GnomeMDIChildConfigFunc func,GtkCallbackMarshal marshal,gpointer data,GtkDestroyNotify notify);





  void set_label_func(GnomeMDIChildLabelFunc func,gpointer data);

  void set_label_func_full(GnomeMDIChildLabelFunc func,GtkCallbackMarshal marshal,gpointer data,GtkDestroyNotify notify);

public:

protected:
  // impl functions

};



}

#endif
