// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-group.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_GROUP_P_H
#define _GNOMEMM_CANVAS_GROUP_P_H
#include <gnome--/private/canvas-item_p.h>
namespace Gnome
{
class CanvasGroup_Class
{
public:

  typedef CanvasGroup           CppObjectType;
  typedef GnomeCanvasGroup           BaseObjectType;
  typedef GnomeCanvasGroupClass      BaseClassType;
  typedef CanvasItem_Class     CppClassParent;
  typedef GnomeCanvasItemClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  // Data
  GtkType type;
};

}
#endif
