// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-text.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_TEXT_H
#define _GNOMEMM_CANVAS_TEXT_H

/* $Id: canvas-text.gen_h,v 1.32 2001/06/22 17:58:30 murrayc Exp $ */

/* canvas-text.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/canvas-item.h>
#include <libgnomeui/gnome-canvas-text.h>

//This conversion is odd: the gdk_font property uses the reverse conversion
//instead of the normal conversion. I dont' know why. murrayc.

namespace Gnome {
class CanvasText;
class CanvasText_Class;
}
namespace Gtk { Gnome::CanvasText *wrap (GnomeCanvasText *o); }
namespace Gnome
{
class CanvasGroup;
class CanvasText : public CanvasItem
{

public:
  typedef CanvasText          CppObjectType;
  typedef CanvasText_Class    CppClassType;
  typedef GnomeCanvasText           BaseObjectType;
  typedef GnomeCanvasTextClass      BaseClassType;

private:
  friend class CanvasText_Class;
  static CppClassType canvas_text_class;

  CanvasText(const CanvasText&);
  CanvasText& operator=(const CanvasText&); // not implemented

protected:
  void   initialize_class();
  explicit CanvasText(GnomeCanvasText *castitem);

public:
  static GtkType get_type();
  GnomeCanvasText* gtkobj()             { return (GnomeCanvasText*)(gtkobject); }
  const GnomeCanvasText* gtkobj() const { return (GnomeCanvasText*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~CanvasText();

private:

public:
  CanvasText(const CanvasGroup &parent,double x, double y, const Gtk::string& text);
  CanvasText(const CanvasGroup &parent);



  void set_text(const Gtk::string&);

  void set_x(gdouble);
  gdouble get_x() const;

  void set_y(gdouble);
  gdouble get_y() const;

  void set_x_offset(gdouble);
  gdouble get_x_offset() const;

  void set_y_offset(gdouble);
  gdouble get_y_offset() const;
  void set_font(const Gdk_Font&);
  void set_font(const Gtk::string&);
  void set_fontset(const Gtk::string&);

  void set_anchor(GtkAnchorType);
  GtkAnchorType get_anchor() const;

  void set_justification(GtkJustification);
  GtkJustification get_justification() const;
  void set_clip(bool);
  bool get_clip() const;

  void set_clip_width(gdouble);
  gdouble get_clip_width() const;

  void set_clip_height(gdouble);
  gdouble get_clip_height() const;
  void set_fill_color(const Gtk::string&);
  void set_fill_color(const Gdk_Color&);
  Gdk_Color get_fill_color() const;

  //FIXME: fill_color_rgba?
  void set_fill_stipple(const Gdk_Pixmap&);
  Gdk_Pixmap get_fill_stipple() const;
  void set_text_width(gdouble);
  gdouble get_text_width() const;

  void set_text_height(gdouble);
  gdouble get_text_height() const;

public:

protected:
  // impl functions

};

}

#endif
