// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-group.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_GROUP_H
#define _GNOMEMM_CANVAS_GROUP_H

// -*- C++ -*-
/* $Id: canvas-group.gen_h,v 1.27 2001/06/22 17:58:30 murrayc Exp $ */

/* canvas-group.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/canvas-item.h>

namespace Gnome {
class CanvasGroup;
class CanvasGroup_Class;
}
namespace Gtk { Gnome::CanvasGroup *wrap (GnomeCanvasGroup *o); }
namespace Gnome
{
class Canvas;

class CanvasGroup : public CanvasItem
{

public:
  typedef CanvasGroup          CppObjectType;
  typedef CanvasGroup_Class    CppClassType;
  typedef GnomeCanvasGroup           BaseObjectType;
  typedef GnomeCanvasGroupClass      BaseClassType;

private:
  friend class CanvasGroup_Class;
  static CppClassType canvas_group_class;

  CanvasGroup(const CanvasGroup&);
  CanvasGroup& operator=(const CanvasGroup&); // not implemented

protected:
  void   initialize_class();
  explicit CanvasGroup(GnomeCanvasGroup *castitem);

public:
  static GtkType get_type();
  GnomeCanvasGroup* gtkobj()             { return (GnomeCanvasGroup*)(gtkobject); }
  const GnomeCanvasGroup* gtkobj() const { return (GnomeCanvasGroup*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~CanvasGroup();

private:

public:
  CanvasGroup();



  friend class Canvas;
  CanvasGroup(const CanvasGroup &parent,
		    gdouble x=0, gdouble y=0);


  void child_bounds(CanvasItem *item);

  void set_x(gdouble);
  gdouble get_x() const;

  void set_y(gdouble);
  gdouble get_y() const;

public:

protected:
  // impl functions

};

}

#endif
