// -*- c++ -*-
//  Generated by gtkmmproc from ./../procbar.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_PROCBAR_H
#define _GNOMEMM_PROCBAR_H

/* $Id: procbar.gen_h,v 1.7 2001/04/24 14:39:35 murrayc Exp $ */


/* procbar.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/box.h>
#include <gtk--/label.h>
#include <libgnomeui/gnome-procbar.h>
#include <vector>

namespace Gnome {
class ProcBar;
class ProcBar_Class;
}
namespace Gtk { Gnome::ProcBar *wrap (GnomeProcBar *o); }
namespace Gnome
{

using std::vector;

class ProcBar : public Gtk::HBox
{

public:
  typedef ProcBar          CppObjectType;
  typedef ProcBar_Class    CppClassType;
  typedef GnomeProcBar           BaseObjectType;
  typedef GnomeProcBarClass      BaseClassType;

private:
  friend class ProcBar_Class;
  static CppClassType proc_bar_class;

  ProcBar(const ProcBar&);
  ProcBar& operator=(const ProcBar&); // not implemented

protected:
  void   initialize_class();
  explicit ProcBar(GnomeProcBar *castitem);

public:
  static GtkType get_type();
  GnomeProcBar* gtkobj()             { return (GnomeProcBar*)(gtkobject); }
  const GnomeProcBar* gtkobj() const { return (GnomeProcBar*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~ProcBar();

private:

public:
  ProcBar();


  ProcBar(const Gtk::Label &label,
		const vector<Gdk_Color*> &colors,
		gint (*cb)(void *));

  void set_values (const vector<unsigned> &values);


  void set_orient(bool vertical);


  void start(gint gtime,gpointer data);


  void stop();

  void update (const vector<Gdk_Color*> &colors);
private:
  void update_internal_gdk_colors(const vector<Gdk_Color*> &colors);
  GdkColor *colors_;

public:

protected:
  // impl functions

};



}


#endif
