SIGC_LIBS=`sigc-config --libs`
SIGC_CFLAGS=`sigc-config --cflags`
GTKMM_LIBS=`gtkmm-config --libs`
GTKMM_CFLAGS=`gtkmm-config --cflags`
GNOMEMM_LIBDIR="-L/usr/X11R6/lib -L/usr/X11R6/lib -L/usr/local/lib $SIGC_LIBS"
GNOMEMM_INCLUDEDIR="-I/usr/X11R6/lib/gnomemm/include -I/usr/X11R6/include -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include/gtk12 $SIGC_CFLAGS $GTKMM_CFLAGS"
GNOMEMM_LIBS="-lgnomemm $SIGC_LIBS $GTKMM_LIBS"
MODULE_VERSION="gnomemm-1.2.2"
