// -*- c++ -*-
//  Generated by gtkmmproc from ./../icon-entry.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_ICON_ENTRY_H
#define _GNOMEMM_ICON_ENTRY_H

/* $Id: icon-entry.gen_h,v 1.5 2000/08/30 18:13:36 kenelson Exp $ */


/* icon-entry.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/box.h>
#include <libgnomeui/gnome-icon-entry.h>
#include <gnome--/file-entry.h>
#include <gnome--/entry.h>
#include <gtk--/entry.h>

namespace Gnome {
class IconEntry;
class IconEntry_Class;
}
namespace Gtk { Gnome::IconEntry *wrap (GnomeIconEntry *o); }
namespace Gnome
{

class IconEntry : public Gtk::VBox
{

public:
  typedef IconEntry          CppObjectType;
  typedef IconEntry_Class    CppClassType;
  typedef GnomeIconEntry           BaseObjectType;
  typedef GnomeIconEntryClass      BaseClassType;

private:
  friend class IconEntry_Class;
  static CppClassType icon_entry_class;

  IconEntry(const IconEntry&);
  IconEntry& operator=(const IconEntry&); // not implemented

protected:
  void   initialize_class();
  explicit IconEntry(GnomeIconEntry *castitem);

public:
  static GtkType get_type();
  GnomeIconEntry* gtkobj()             { return (GnomeIconEntry*)(gtkobject); }
  const GnomeIconEntry* gtkobj() const { return (GnomeIconEntry*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~IconEntry();

private:

public:



  IconEntry(const Gtk::string &history_id,
		  const Gtk::string &browse_dialog_title);


  void set_pixmap_subdir(const Gtk::string& subdir);


  void set_icon(const Gtk::string& filename);


  Gtk::string get_filename();

  Gnome::Entry* gnome_entry();
  Gtk::Entry* gtk_entry();
  Gnome::FileEntry* gnome_file_entry();

public:

protected:
  // impl functions

};



}


#endif
