// -*- c++ -*-
//  Generated by gtkmmproc from ./../pixmap.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_PIXMAP_H
#define _GNOMEMM_PIXMAP_H

// -*- C++ -*- // this is for the .gen_h, I realize gensig puts one in
/* $Id: pixmap.gen_h,v 1.23 2001/03/28 12:28:41 murrayc Exp $ */

/* pixmap.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/widget.h>
#include <libgnomeui/gnome-pixmap.h>
#include <gnome--/imlib.h>
#include <libgnome/gnome-util.h> //For gnome_pixmap_file().

namespace Gnome {
class Pixmap;
class Pixmap_Class;
}
namespace Gtk { Gnome::Pixmap *wrap (GnomePixmap *o); }
namespace Gnome
{
class Pixmap : public Gtk::Widget
{

public:
  typedef Pixmap          CppObjectType;
  typedef Pixmap_Class    CppClassType;
  typedef GnomePixmap           BaseObjectType;
  typedef GnomePixmapClass      BaseClassType;

private:
  friend class Pixmap_Class;
  static CppClassType pixmap_class;

  Pixmap(const Pixmap&);
  Pixmap& operator=(const Pixmap&); // not implemented

protected:
  void   initialize_class();
  explicit Pixmap(GnomePixmap *castitem);

public:
  static GtkType get_type();
  GnomePixmap* gtkobj()             { return (GnomePixmap*)(gtkobject); }
  const GnomePixmap* gtkobj() const { return (GnomePixmap*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~Pixmap();

private:

public:
  Pixmap();



  Pixmap (const Gtk::string &filename);

  Pixmap (const Gtk::string &filename,
		int width,
		int height);

  Pixmap (char ** xpm_data);

  Pixmap (char ** xpm_data,
		int width,
		int height);

  Pixmap (const Gdk_Imlib::Image &im);

  Pixmap (const Gdk_Imlib::Image &im,
		int width,
		int height);

  Pixmap (unsigned char * rgb_data,
		unsigned char * alpha,
		int rgb_width,
		int rgb_height);

  Pixmap (unsigned char * rgb_data,
		unsigned char * alpha,
		int rgb_width,
		int rgb_height,
		const Gdk_Imlib::Color &shape_color);

  Pixmap (unsigned char * rgb_data,
		unsigned char * alpha,
		int rgb_width,
		int rgb_height,
		int width,
		int height);

  void load (const Gtk::string &filename, int width = 0, int height = 0);


  void load(char** xpm_data);


  void load(char** xpm_data,int width,int height);

  void load(unsigned char* rgb_data,unsigned char* alpha,int rgb_width,int rgb_height);

  // gnome_pixmap_load_rgb_d_shaped
  void load (unsigned char *data,
	     unsigned char *alpha,
	     int rgb_width,
	     int rgb_height,
	     const Gdk_Imlib::Color &shape_color);

  void load(unsigned char* data,unsigned char* alpha,int rgb_width,int rgb_height,int width,int height);


  // gnome_pixmap_load_imlib - gnome_pixmap_load_imlib_at_size
  void load    (const Gdk_Imlib::Image &im,
		int width = 0,
		int height = 0);

  //- Lookup actual filepath for the pixmap.
  //- Returns a filename from the GNOMEDIR tree or from the
  //- GNOME installation directory for the pixmap directory ($prefix/share/pixmaps),
  //- or an empty string if the file does not exist.
  static Gtk::string find_file(const Gtk::string& filename);

public:

protected:
  // impl functions

};

}

#endif
