// -*- c++ -*-
//  Generated by gtkmmproc from ./../file-entry.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_FILE_ENTRY_H
#define _GNOMEMM_FILE_ENTRY_H

/* $Id: file-entry.gen_h,v 1.9 2000/08/30 18:13:36 kenelson Exp $ */


/* file-entry.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/box.h>
#include <libgnomeui/gnome-file-entry.h>

namespace Gnome {
class FileEntry;
class FileEntry_Class;
}
namespace Gtk { Gnome::FileEntry *wrap (GnomeFileEntry *o); }
namespace Gnome
{
class FileEntry : public Gtk::HBox
{

public:
  typedef FileEntry          CppObjectType;
  typedef FileEntry_Class    CppClassType;
  typedef GnomeFileEntry           BaseObjectType;
  typedef GnomeFileEntryClass      BaseClassType;

private:
  friend class FileEntry_Class;
  static CppClassType file_entry_class;

  FileEntry(const FileEntry&);
  FileEntry& operator=(const FileEntry&); // not implemented

protected:
  void   initialize_class();
  explicit FileEntry(GnomeFileEntry *castitem);

public:
  static GtkType get_type();
  GnomeFileEntry* gtkobj()             { return (GnomeFileEntry*)(gtkobject); }
  const GnomeFileEntry* gtkobj() const { return (GnomeFileEntry*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~FileEntry();

private:

public:
  FileEntry();



  FileEntry(const Gtk::string &history_id,
		  const Gtk::string &browse_dialog_title);

  Gtk::Widget* gnome_entry();
  Gtk::Widget* gtk_entry();


  void set_title(const Gtk::string& browse_dialog_title);


  void set_default_path(const Gtk::string& path);


  void set_directory(bool directory_entry);

  Gtk::string get_full_path(bool file_must_exist) const;


  void set_modal(bool is_modal);

public:

  union
    {
      CppObjectType * file_entry_self;
      Gtk::ProxySignal0<void,CppObjectType,BaseObjectType,0> browse_clicked;
    };

protected:
  // impl functions
    virtual void browse_clicked_impl();

};



}


#endif
