// -*- c++ -*-
//  Generated by gtkmmproc from ./../propertybox.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_PROPERTYBOX_H
#define _GNOMEMM_PROPERTYBOX_H

/* $Id: propertybox.gen_h,v 1.7 2001/08/03 20:00:29 murrayc Exp $ */


/* propertybox.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/dialog.h>
#include <libgnomeui/gnome-propertybox.h>

namespace Gnome {
class PropertyBox;
class PropertyBox_Class;
}
namespace Gtk { Gnome::PropertyBox *wrap (GnomePropertyBox *o); }
namespace Gnome
{
//: Dialog with Apply, OK, Cancel, and Help buttons.
//- Unlike GnomePropertyBox in C, Gnome::PropertyBox does not self-destruct when
//- run() or run_and_close() returns, so you can use it again.
//- Just delete it later, like any other Window.

class PropertyBox : public Dialog
{

public:
  typedef PropertyBox          CppObjectType;
  typedef PropertyBox_Class    CppClassType;
  typedef GnomePropertyBox           BaseObjectType;
  typedef GnomePropertyBoxClass      BaseClassType;

private:
  friend class PropertyBox_Class;
  static CppClassType property_box_class;

  PropertyBox(const PropertyBox&);
  PropertyBox& operator=(const PropertyBox&); // not implemented

protected:
  void   initialize_class();
  explicit PropertyBox(GnomePropertyBox *castitem);

public:
  static GtkType get_type();
  GnomePropertyBox* gtkobj()             { return (GnomePropertyBox*)(gtkobject); }
  const GnomePropertyBox* gtkobj() const { return (GnomePropertyBox*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~PropertyBox();

private:

public:
  PropertyBox();




  void changed();


  void set_modified(bool state);

  gint append_page(Gtk::Widget &child, Gtk::Widget &tab_label);

public:

  union
    {
      CppObjectType * property_box_self;
      Gtk::ProxySignal1<void,gint,CppObjectType,BaseObjectType,0> apply;
      Gtk::ProxySignal1<void,gint,CppObjectType,BaseObjectType,1> help;
    };

protected:
  // impl functions
    virtual void apply_impl(gint page_num);
    virtual void help_impl(gint page_num);

};



}


#endif
