/* $Id: gnome--.h,v 1.14 2000/09/02 21:37:47 kenelson Exp $ */
#ifndef GNOME_MINUS_MINUS_H
#define GNOME_MINUS_MINUS_H 1

#include <gtk--.h>

#include <gnome--/animator.h>
#include <gnome--/about.h>
#include <gnome--/app.h>
#include <gnome--/appbar.h>
#include <gnome--/calculator.h>
#include <gnome--/canvas-ellipse.h>
#include <gnome--/canvas-group.h>
#include <gnome--/canvas-image.h>
#include <gnome--/canvas-item.h>
#include <gnome--/canvas-line.h>
#include <gnome--/canvas-polygon.h>
#include <gnome--/canvas-rect-ellipse.h>
#include <gnome--/canvas-rect.h>
#include <gnome--/canvas-text.h>
#include <gnome--/canvas-widget.h>
#include <gnome--/canvas.h>
#include <gnome--/client.h>
#include <gnome--/clock.h>
#include <gnome--/color-picker.h>
#include <gnome--/dateedit.h>
#include <gnome--/dentry-edit.h>
#include <gnome--/dial.h>
#include <gnome--/dialog.h>
#include <gnome--/dock-item.h>
#include <gnome--/dock-layout.h>
#include <gnome--/dock.h>
#include <gnome--/druid-page-finish.h>
#include <gnome--/druid-page-standard.h>
#include <gnome--/druid-page-start.h>
#include <gnome--/druid-page.h>
#include <gnome--/druid.h>
#include <gnome--/entry.h>
#include <gnome--/file-entry.h>
#include <gnome--/font-picker.h>
#include <gnome--/icon-entry.h>
#include <gnome--/icon-item.h>
#include <gnome--/icon-list.h>
#include <gnome--/icon-sel.h>
#include <gnome--/less.h>
#include <gnome--/main.h>
#include <gnome--/mdi-child.h>
#include <gnome--/mdi-generic-child.h>
#include <gnome--/mdi.h>
#include <gnome--/messagebox.h>
#include <gnome--/number-entry.h>
#include <gnome--/paper-selector.h>
#include <gnome--/pixmap-entry.h>
#include <gnome--/pixmap.h>
#include <gnome--/pixmapmenuitem.h>
#include <gnome--/procbar.h>
#include <gnome--/propertybox.h>
#include <gnome--/stock.h>

#endif /* GNOME_MINUS_MINUS_H */
