// -*- c++ -*-
//  Generated by gtkmmproc from ./../dentry-edit.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DENTRY_EDIT_P_H
#define _GNOMEMM_DENTRY_EDIT_P_H
#include <gtk--/private/object_p.h>
namespace Gnome
{
class DEntryEdit_Class
{
public:

  typedef DEntryEdit           CppObjectType;
  typedef GnomeDEntryEdit           BaseObjectType;
  typedef GnomeDEntryEditClass      BaseClassType;
  typedef Gtk::Object_Class     CppClassParent;
  typedef GtkObjectClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void changed_callback(GnomeDEntryEdit* o_);
  static void icon_changed_callback(GnomeDEntryEdit* o_);
  static void name_changed_callback(GnomeDEntryEdit* o_);
  // Data
  GtkType type;
};

}
#endif
