// -*- c++ -*-
//  Generated by gtkmmproc from ./../file-entry.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_FILE_ENTRY_P_H
#define _GNOMEMM_FILE_ENTRY_P_H
#include <gtk--/private/box_p.h>
namespace Gnome
{
class FileEntry_Class
{
public:

  typedef FileEntry           CppObjectType;
  typedef GnomeFileEntry           BaseObjectType;
  typedef GnomeFileEntryClass      BaseClassType;
  typedef Gtk::HBox_Class     CppClassParent;
  typedef GtkHBoxClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void browse_clicked_callback(GnomeFileEntry* o_);
  // Data
  GtkType type;
};

}
#endif
