// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-ellipse.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_ELLIPSE_H
#define _GNOMEMM_CANVAS_ELLIPSE_H

// -*- C++ -*-
/* $Id: canvas-ellipse.gen_h,v 1.29 2001/04/30 05:47:13 kenelson Exp $ */

/* canvas-ellipse.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/canvas-item.h>
#include <gnome--/canvas-group.h>
#include <gnome--/canvas-rect-ellipse.h>

namespace Gnome {
class CanvasEllipse;
class CanvasEllipse_Class;
}
namespace Gtk { Gnome::CanvasEllipse *wrap (GnomeCanvasEllipse *o); }
namespace Gnome
{
class CanvasEllipse : public CanvasRE
{

public:
  typedef CanvasEllipse          CppObjectType;
  typedef CanvasEllipse_Class    CppClassType;
  typedef GnomeCanvasEllipse           BaseObjectType;
  typedef GnomeCanvasEllipseClass      BaseClassType;

private:
  friend class CanvasEllipse_Class;
  static CppClassType canvas_ellipse_class;

  CanvasEllipse(const CanvasEllipse&);
  CanvasEllipse& operator=(const CanvasEllipse&); // not implemented

protected:
  void   initialize_class();
  explicit CanvasEllipse(GnomeCanvasEllipse *castitem);

public:
  static GtkType get_type();
  GnomeCanvasEllipse* gtkobj()             { return (GnomeCanvasEllipse*)(gtkobject); }
  const GnomeCanvasEllipse* gtkobj() const { return (GnomeCanvasEllipse*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~CanvasEllipse();

private:

public:
  CanvasEllipse(const CanvasGroup &parent);
  CanvasEllipse(const CanvasGroup &parent,gdouble x1,gdouble y1,gdouble x2,gdouble y2);

public:

protected:
  // impl functions

};

}

#endif
