// -*- c++ -*-
//  Generated by gtkmmproc from ./../dock-item.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DOCK_ITEM_P_H
#define _GNOMEMM_DOCK_ITEM_P_H
#include <gtk--/private/bin_p.h>
namespace Gnome
{
class DockItem_Class
{
public:

  typedef DockItem           CppObjectType;
  typedef GnomeDockItem           BaseObjectType;
  typedef GnomeDockItemClass      BaseClassType;
  typedef Gtk::Bin_Class     CppClassParent;
  typedef GtkBinClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void dock_drag_begin_callback(GnomeDockItem* o_);
  static void dock_drag_motion_callback(GnomeDockItem* o_,gint p0,gint p1);
  static void dock_drag_end_callback(GnomeDockItem* o_);
  static void dock_detach_callback(GnomeDockItem* o_);
  // Data
  GtkType type;
};

}
#endif
