// -*- c++ -*-
//  Generated by gtkmmproc from ./../dateedit.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DATEEDIT_H
#define _GNOMEMM_DATEEDIT_H

/* $Id: dateedit.gen_h,v 1.5 2000/05/07 04:59:59 kenelson Exp $ */


/* dateedit.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <time.h>
#include <gtk--/box.h>
#include <libgnomeui/gnome-dateedit.h>

namespace Gnome {
class DateEdit;
class DateEdit_Class;
}
namespace Gtk { Gnome::DateEdit *wrap (GnomeDateEdit *o); }
namespace Gnome
{
//: Date and time entry widget.
//- The GnomeDateEdit widget provides a way to enter dates and
//- times with a helper calendar to let the user select the date.
class DateEdit : public Gtk::HBox
{

public:
  typedef DateEdit          CppObjectType;
  typedef DateEdit_Class    CppClassType;
  typedef GnomeDateEdit           BaseObjectType;
  typedef GnomeDateEditClass      BaseClassType;

private:
  friend class DateEdit_Class;
  static CppClassType date_edit_class;

  DateEdit(const DateEdit&);
  DateEdit& operator=(const DateEdit&); // not implemented

protected:
  void   initialize_class();
  explicit DateEdit(GnomeDateEdit *castitem);

public:
  static GtkType get_type();
  GnomeDateEdit* gtkobj()             { return (GnomeDateEdit*)(gtkobject); }
  const GnomeDateEdit* gtkobj() const { return (GnomeDateEdit*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~DateEdit();

private:

public:
  DateEdit();




  void set_time(time_t the_time);


  void set_popup_range(int low_hour,int up_hour);


  time_t get_date();


  void set_flags(GnomeDateEditFlags flags);


  int get_flags();

public:

  union
    {
      CppObjectType * date_edit_self;
      Gtk::ProxySignal0<void,CppObjectType,BaseObjectType,0> date_changed;
      Gtk::ProxySignal0<void,CppObjectType,BaseObjectType,1> time_changed;
    };

protected:
  // impl functions
    virtual void date_changed_impl();
    virtual void time_changed_impl();

};



}


#endif
