// -*- c++ -*-
//  Generated by gtkmmproc from ./../druid-page-standard.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DRUID_PAGE_STANDARD_H
#define _GNOMEMM_DRUID_PAGE_STANDARD_H

/* $Id: druid-page-standard.gen_h,v 1.6 2001/04/24 14:39:35 murrayc Exp $ */


/* druid-page-standard.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/druid-page.h>
#include <libgnomeui/gnome-druid-page-standard.h>
#include <gnome--/imlib.h>

namespace Gtk {
class VBox;
}

namespace Gnome {
class DruidPageStandard;
class DruidPageStandard_Class;
}
namespace Gtk { Gnome::DruidPageStandard *wrap (GnomeDruidPageStandard *o); }
namespace Gnome
{
class DruidPageStandard : public DruidPage
{

public:
  typedef DruidPageStandard          CppObjectType;
  typedef DruidPageStandard_Class    CppClassType;
  typedef GnomeDruidPageStandard           BaseObjectType;
  typedef GnomeDruidPageStandardClass      BaseClassType;

private:
  friend class DruidPageStandard_Class;
  static CppClassType druid_page_standard_class;

  DruidPageStandard(const DruidPageStandard&);
  DruidPageStandard& operator=(const DruidPageStandard&); // not implemented

protected:
  void   initialize_class();
  explicit DruidPageStandard(GnomeDruidPageStandard *castitem);

public:
  static GtkType get_type();
  GnomeDruidPageStandard* gtkobj()             { return (GnomeDruidPageStandard*)(gtkobject); }
  const GnomeDruidPageStandard* gtkobj() const { return (GnomeDruidPageStandard*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~DruidPageStandard();

private:

public:

  DruidPageStandard();
  DruidPageStandard(const Gtk::string &title,
			  const Gdk_Imlib::Image &logo_image);





  void set_bg_color(const Gdk_Color& color);


  void set_logo_bg_color(const Gdk_Color& color);


  void set_title_color(const Gdk_Color& color);


  void set_title(const Gtk::string& title);


  void set_logo(const Gdk_Imlib::Image& logo_image);

  //: Pack widgets into the VBox.
  Gtk::VBox* get_vbox() const;

public:

protected:
  // impl functions

};



}

#endif
