// -*- c++ -*-
//  Generated by gtkmmproc from ./../druid-page-standard.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DRUID_PAGE_STANDARD_P_H
#define _GNOMEMM_DRUID_PAGE_STANDARD_P_H
#include <gnome--/private/druid-page_p.h>

namespace Gnome
{
class DruidPageStandard_Class
{
public:

  typedef DruidPageStandard           CppObjectType;
  typedef GnomeDruidPageStandard           BaseObjectType;
  typedef GnomeDruidPageStandardClass      BaseClassType;
  typedef DruidPage_Class     CppClassParent;
  typedef GnomeDruidPageClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  // Data
  GtkType type;
};

}
#endif
