// -*- c++ -*-
//  Generated by gtkmmproc from ./../font-picker.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_FONT_PICKER_H
#define _GNOMEMM_FONT_PICKER_H

/* $Id: font-picker.gen_h,v 1.5 2000/08/30 18:13:36 kenelson Exp $ */


/* font-picker.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/button.h>
#include <libgnomeui/gnome-font-picker.h>

namespace Gnome {
class FontPicker;
class FontPicker_Class;
}
namespace Gtk { Gnome::FontPicker *wrap (GnomeFontPicker *o); }
namespace Gnome
{
class FontPicker : public Gtk::Button
{

public:
  typedef FontPicker          CppObjectType;
  typedef FontPicker_Class    CppClassType;
  typedef GnomeFontPicker           BaseObjectType;
  typedef GnomeFontPickerClass      BaseClassType;

private:
  friend class FontPicker_Class;
  static CppClassType font_picker_class;

  FontPicker(const FontPicker&);
  FontPicker& operator=(const FontPicker&); // not implemented

protected:
  void   initialize_class();
  explicit FontPicker(GnomeFontPicker *castitem);

public:
  static GtkType get_type();
  GnomeFontPicker* gtkobj()             { return (GnomeFontPicker*)(gtkobject); }
  const GnomeFontPicker* gtkobj() const { return (GnomeFontPicker*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~FontPicker();

private:

public:
  FontPicker();




  void set_title(const Gtk::string& title);


  GnomeFontPickerMode get_mode();


  void set_mode(GnomeFontPickerMode mode);


  void set_use_font_in_label(bool use_font_in_label,gint size);


  void set_show_size(bool show_size);


  void uw_set_widget(Gtk::Widget& widget);


  Gtk::string get_font_name();

  Gdk_Font get_font();


  bool set_font_name(const Gtk::string& fontname);


  Gtk::string get_preview_text();


  void set_preview_text(const Gtk::string& text);

public:

  union
    {
      CppObjectType * font_picker_self;
      Gtk::ProxySignal1<void,gchar*,CppObjectType,BaseObjectType,0> font_set;
    };

protected:
  // impl functions
    virtual void font_set_impl(gchar* p0);

};



}


#endif
