// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-polygon.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_POLYGON_H
#define _GNOMEMM_CANVAS_POLYGON_H

/* $Id: canvas-polygon.gen_h,v 1.12 2001/06/22 17:58:30 murrayc Exp $ */


/* canvas-polygon.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/canvas-item.h>
#include <gnome--/canvas-line.h>
#include <libgnomeui/gnome-canvas-polygon.h>

namespace Gnome {
class CanvasPolygon;
class CanvasPolygon_Class;
}
namespace Gtk { Gnome::CanvasPolygon *wrap (GnomeCanvasPolygon *o); }
namespace Gnome
{

class CanvasPolygon : public CanvasItem
{

public:
  typedef CanvasPolygon          CppObjectType;
  typedef CanvasPolygon_Class    CppClassType;
  typedef GnomeCanvasPolygon           BaseObjectType;
  typedef GnomeCanvasPolygonClass      BaseClassType;

private:
  friend class CanvasPolygon_Class;
  static CppClassType canvas_polygon_class;

  CanvasPolygon(const CanvasPolygon&);
  CanvasPolygon& operator=(const CanvasPolygon&); // not implemented

protected:
  void   initialize_class();
  explicit CanvasPolygon(GnomeCanvasPolygon *castitem);

public:
  static GtkType get_type();
  GnomeCanvasPolygon* gtkobj()             { return (GnomeCanvasPolygon*)(gtkobject); }
  const GnomeCanvasPolygon* gtkobj() const { return (GnomeCanvasPolygon*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~CanvasPolygon();

private:

public:
  CanvasPolygon(const CanvasGroup &parent,const CanvasPoints& points);
  CanvasPolygon(const CanvasGroup &parent);



  void set_points(const CanvasPoints&);

  void set_fill_color(const Gtk::string&);
  void set_fill_color(const Gdk_Color&);
  Gdk_Color get_fill_color() const;

  //FIXME: fill_color_rgba?
  void set_fill_stipple(const Gdk_Pixmap&);
  Gdk_Pixmap get_fill_stipple() const;
  void set_outline_color(const Gtk::string&);
  void set_outline_color(const Gdk_Color&);
  Gdk_Color get_outline_color() const;

  //FIXME: outline_color_rgba?
  void set_outline_stipple(const Gdk_Pixmap&);
  Gdk_Pixmap get_outline_stipple() const;
  void set_width_pixels(guint);
  void set_width_units(gdouble);

public:

protected:
  // impl functions

};



}


#endif
