// -*- c++ -*-
//  Generated by gtkmmproc from ./../dock-layout.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DOCK_LAYOUT_H
#define _GNOMEMM_DOCK_LAYOUT_H

/* $Id: dock-layout.gen_h,v 1.5 2000/08/29 18:36:29 kenelson Exp $ */


/* dock-layout.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/object.h>
#include <gnome--/dock.h>
#include <gnome--/dock-item.h>
#include <libgnomeui/gnome-dock-layout.h>

namespace Gnome {
class DockLayout;
class DockLayout_Class;
}
namespace Gtk { Gnome::DockLayout *wrap (GnomeDockLayout *o); }
namespace Gnome
{

class DockLayout : public Gtk::Object
{

public:
  typedef DockLayout          CppObjectType;
  typedef DockLayout_Class    CppClassType;
  typedef GnomeDockLayout           BaseObjectType;
  typedef GnomeDockLayoutClass      BaseClassType;

private:
  friend class DockLayout_Class;
  static CppClassType dock_layout_class;

  DockLayout(const DockLayout&);
  DockLayout& operator=(const DockLayout&); // not implemented

protected:
  void   initialize_class();
  explicit DockLayout(GnomeDockLayout *castitem);

public:
  static GtkType get_type();
  GnomeDockLayout* gtkobj()             { return (GnomeDockLayout*)(gtkobject); }
  const GnomeDockLayout* gtkobj() const { return (GnomeDockLayout*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~DockLayout();

private:

public:
  DockLayout();

  bool add_item(DockItem& item,GnomeDockPlacement placement,gint band_num,gint band_position,gint offset);

  bool add_floating_item(DockItem& item,gint x,gint y,GtkOrientation orientation);

  //TODO: Wrap GnomeDockLayoutItem?


  GnomeDockLayoutItem* get_item(DockItem& item);




  GnomeDockLayoutItem* get_item_by_name(const Gtk::nstring& name);




  bool remove_item(DockItem& item);




  bool remove_item_by_name(const Gtk::nstring& name);


  Gtk::nstring create_string();




  bool parse_string(const Gtk::nstring& str);



  bool add_to_dock(Dock& dock);

public:

protected:
  // impl functions

};



}

#endif
