// -*- c++ -*-
//  Generated by gtkmmproc from ./../number-entry.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_NUMBER_ENTRY_H
#define _GNOMEMM_NUMBER_ENTRY_H

/* $Id: number-entry.gen_h,v 1.7 2001/04/24 14:39:35 murrayc Exp $ */


/* number-entry.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/box.h>
#include <gnome--/entry.h>
#include <gtk--/entry.h>
#include <libgnomeui/gnome-number-entry.h>

namespace Gnome {
class NumberEntry;
class NumberEntry_Class;
}
namespace Gtk { Gnome::NumberEntry *wrap (GnomeNumberEntry *o); }
namespace Gnome
{
class NumberEntry : public Gtk::HBox
{

public:
  typedef NumberEntry          CppObjectType;
  typedef NumberEntry_Class    CppClassType;
  typedef GnomeNumberEntry           BaseObjectType;
  typedef GnomeNumberEntryClass      BaseClassType;

private:
  friend class NumberEntry_Class;
  static CppClassType number_entry_class;

  NumberEntry(const NumberEntry&);
  NumberEntry& operator=(const NumberEntry&); // not implemented

protected:
  void   initialize_class();
  explicit NumberEntry(GnomeNumberEntry *castitem);

public:
  static GtkType get_type();
  GnomeNumberEntry* gtkobj()             { return (GnomeNumberEntry*)(gtkobject); }
  const GnomeNumberEntry* gtkobj() const { return (GnomeNumberEntry*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~NumberEntry();

private:

public:
  NumberEntry();



  Gnome::Entry* gnome_entry();
  Gtk::Entry* gtk_entry();


  void set_title(const Gtk::string& calc_dialog_title);


  gdouble get_number();

public:

protected:
  // impl functions

};



}


#endif
