// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-image.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_IMAGE_H
#define _GNOMEMM_CANVAS_IMAGE_H

// -*- C++ -*-
/* $Id: canvas-image.gen_h,v 1.27 2001/04/30 05:47:13 kenelson Exp $ */

/* canvas-image.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/imlib.h>
#include <gnome--/canvas-item.h>
#include <libgnomeui/gnome-canvas-image.h>

namespace Gnome {
class CanvasImage;
class CanvasImage_Class;
}
namespace Gtk { Gnome::CanvasImage *wrap (GnomeCanvasImage *o); }
namespace Gnome
{
class CanvasGroup;
class CanvasImage : public CanvasItem
{

public:
  typedef CanvasImage          CppObjectType;
  typedef CanvasImage_Class    CppClassType;
  typedef GnomeCanvasImage           BaseObjectType;
  typedef GnomeCanvasImageClass      BaseClassType;

private:
  friend class CanvasImage_Class;
  static CppClassType canvas_image_class;

  CanvasImage(const CanvasImage&);
  CanvasImage& operator=(const CanvasImage&); // not implemented

protected:
  void   initialize_class();
  explicit CanvasImage(GnomeCanvasImage *castitem);

public:
  static GtkType get_type();
  GnomeCanvasImage* gtkobj()             { return (GnomeCanvasImage*)(gtkobject); }
  const GnomeCanvasImage* gtkobj() const { return (GnomeCanvasImage*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~CanvasImage();

private:

public:
  CanvasImage(const CanvasGroup &parent,
              gdouble x, gdouble y,const Gdk_Imlib::Image& image);
  CanvasImage(const CanvasGroup &parentx);



  void set_image  (const Gdk_Imlib::Image &image);

  void set_x(gdouble);
  gdouble get_x() const;

  void set_y(gdouble);
  gdouble get_y() const;
  void set_width(gdouble);
  gdouble get_width() const;

  void set_height(gdouble);
  gdouble get_height() const;
  void set_anchor(GtkAnchorType);
  GtkAnchorType get_anchor() const;

public:

protected:
  // impl functions

};

}

#endif
