// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-rect.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_RECT_H
#define _GNOMEMM_CANVAS_RECT_H

/* $Id: canvas-rect.gen_h,v 1.29 2001/04/30 05:47:13 kenelson Exp $ */

/* canvas-rect.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/canvas-item.h>
#include <gnome--/canvas-rect-ellipse.h>

namespace Gnome {
class CanvasRect;
class CanvasRect_Class;
}
namespace Gtk { Gnome::CanvasRect *wrap (GnomeCanvasRect *o); }
namespace Gnome
{

class CanvasGroup;

class CanvasRect : public CanvasRE
{

public:
  typedef CanvasRect          CppObjectType;
  typedef CanvasRect_Class    CppClassType;
  typedef GnomeCanvasRect           BaseObjectType;
  typedef GnomeCanvasRectClass      BaseClassType;

private:
  friend class CanvasRect_Class;
  static CppClassType canvas_rect_class;

  CanvasRect(const CanvasRect&);
  CanvasRect& operator=(const CanvasRect&); // not implemented

protected:
  void   initialize_class();
  explicit CanvasRect(GnomeCanvasRect *castitem);

public:
  static GtkType get_type();
  GnomeCanvasRect* gtkobj()             { return (GnomeCanvasRect*)(gtkobject); }
  const GnomeCanvasRect* gtkobj() const { return (GnomeCanvasRect*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~CanvasRect();

private:

public:
  CanvasRect(const CanvasGroup &parent,gdouble x1,gdouble y1,gdouble x2,gdouble y2);
  CanvasRect(const CanvasGroup &parent);

public:

protected:
  // impl functions

};

}

#endif
