// -*- c++ -*-
//  Generated by gtkmmproc from ./../icon-sel.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_ICON_SEL_H
#define _GNOMEMM_ICON_SEL_H

/* $Id: icon-sel.gen_h,v 1.5 2001/04/24 14:39:35 murrayc Exp $ */


/* icon-sel.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/box.h>
#include <libgnomeui/gnome-icon-sel.h>

namespace Gnome {
class IconSelection;
class IconSelection_Class;
}
namespace Gtk { Gnome::IconSelection *wrap (GnomeIconSelection *o); }
namespace Gnome
{
class IconSelection : public Gtk::VBox
{

public:
  typedef IconSelection          CppObjectType;
  typedef IconSelection_Class    CppClassType;
  typedef GnomeIconSelection           BaseObjectType;
  typedef GnomeIconSelectionClass      BaseClassType;

private:
  friend class IconSelection_Class;
  static CppClassType icon_selection_class;

  IconSelection(const IconSelection&);
  IconSelection& operator=(const IconSelection&); // not implemented

protected:
  void   initialize_class();
  explicit IconSelection(GnomeIconSelection *castitem);

public:
  static GtkType get_type();
  GnomeIconSelection* gtkobj()             { return (GnomeIconSelection*)(gtkobject); }
  const GnomeIconSelection* gtkobj() const { return (GnomeIconSelection*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~IconSelection();

private:

public:
  IconSelection();




  void add_defaults();


  void add_directory(const Gtk::string& dir);


  void show_icons();


  void clear(bool not_shown);


  Gtk::string get_icon(bool full_path);


  void select_icon(const Gtk::string& filename);


  void stop_loading();

public:

protected:
  // impl functions

};



}


#endif
