// -*- c++ -*-
//  Generated by gtkmmproc from ./../pixmap-entry.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_PIXMAP_ENTRY_H
#define _GNOMEMM_PIXMAP_ENTRY_H

/* $Id: pixmap-entry.gen_h,v 1.8 2000/09/01 15:51:40 kenelson Exp $ */


/* pixmap-entry.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/box.h>
#include <gnome--/file-entry.h>
#include <gnome--/entry.h>
#include <gtk--/entry.h>
#include <libgnomeui/gnome-pixmap-entry.h>

namespace Gnome {
class PixmapEntry;
class PixmapEntry_Class;
}
namespace Gtk { Gnome::PixmapEntry *wrap (GnomePixmapEntry *o); }
namespace Gnome
{
class PixmapEntry : public Gtk::VBox
{

public:
  typedef PixmapEntry          CppObjectType;
  typedef PixmapEntry_Class    CppClassType;
  typedef GnomePixmapEntry           BaseObjectType;
  typedef GnomePixmapEntryClass      BaseClassType;

private:
  friend class PixmapEntry_Class;
  static CppClassType pixmap_entry_class;

  PixmapEntry(const PixmapEntry&);
  PixmapEntry& operator=(const PixmapEntry&); // not implemented

protected:
  void   initialize_class();
  explicit PixmapEntry(GnomePixmapEntry *castitem);

public:
  static GtkType get_type();
  GnomePixmapEntry* gtkobj()             { return (GnomePixmapEntry*)(gtkobject); }
  const GnomePixmapEntry* gtkobj() const { return (GnomePixmapEntry*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~PixmapEntry();

private:

public:
  PixmapEntry();



  PixmapEntry(const Gtk::string &history_id,
		    const Gtk::string &browse_dialog_title,
		    bool do_preview);

  Gnome::FileEntry* gnome_file_entry();
  Gnome::Entry* gnome_entry();
  Gtk::Entry* gtk_entry();

  Gtk::string get_filename() const;


  void set_pixmap_subdir(const Gtk::string& subdir);


  void set_preview(bool do_preview);


  void set_preview_size(gint preview_w,gint preview_h);

public:

protected:
  // impl functions

};



}


#endif
