// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-item.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_ITEM_P_H
#define _GNOMEMM_CANVAS_ITEM_P_H
#include <gtk--/private/object_p.h>
namespace Gnome
{
class CanvasItem_Class
{
public:

  typedef CanvasItem           CppObjectType;
  typedef GnomeCanvasItem           BaseObjectType;
  typedef GnomeCanvasItemClass      BaseClassType;
  typedef Gtk::Object_Class     CppClassParent;
  typedef GtkObjectClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void update_callback(GnomeCanvasItem* o_,double* p0,ArtSVP* p1,int p2);
  static void realize_callback(GnomeCanvasItem* o_);
  static void unrealize_callback(GnomeCanvasItem* o_);
  static void map_callback(GnomeCanvasItem* o_);
  static void unmap_callback(GnomeCanvasItem* o_);
  static ArtUta* coverage_callback(GnomeCanvasItem* o_);
  static void draw_callback(GnomeCanvasItem* o_,GdkDrawable* p0,int p1,int p2,int p3,int p4);
  static void translate_callback(GnomeCanvasItem* o_,double p0,double p1);
  static void bounds_callback(GnomeCanvasItem* o_,double* p0,double* p1,double* p2,double* p3);
  static gint event_callback(GnomeCanvasItem* o_,GdkEvent* p0);
  // Data
  GtkType type;
};

}
#endif
