// -*- c++ -*-
//  Generated by gtkmmproc from ./../dial.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DIAL_P_H
#define _GNOMEMM_DIAL_P_H
#include <gtk--/private/widget_p.h>
namespace Gtk
{
class Dial_Class
{
public:

  typedef Dial           CppObjectType;
  typedef GtkDial           BaseObjectType;
  typedef GtkDialClass      BaseClassType;
  typedef Widget_Class     CppClassParent;
  typedef GtkWidgetClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  // Data
  GtkType type;
};

}
#endif
