// -*- c++ -*-
//  Generated by gtkmmproc from ./../about.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_ABOUT_H
#define _GNOMEMM_ABOUT_H

// -*- C++ -*-

/* $Id: about.gen_h,v 1.22 2001/04/24 14:39:35 murrayc Exp $ */

/* about.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/dialog.h>
#include <libgnomeui/gnome-about.h>

namespace Gnome {
class About;
class About_Class;
}
namespace Gtk { Gnome::About *wrap (GnomeAbout *o); }
namespace Gnome
{
class About : public Dialog
{

public:
  typedef About          CppObjectType;
  typedef About_Class    CppClassType;
  typedef GnomeAbout           BaseObjectType;
  typedef GnomeAboutClass      BaseClassType;

private:
  friend class About_Class;
  static CppClassType about_class;

  About(const About&);
  About& operator=(const About&); // not implemented

protected:
  void   initialize_class();
  explicit About(GnomeAbout *castitem);

public:
  static GtkType get_type();
  GnomeAbout* gtkobj()             { return (GnomeAbout*)(gtkobject); }
  const GnomeAbout* gtkobj() const { return (GnomeAbout*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~About();

private:

public:

  About(const Gtk::string &title,
	      const Gtk::string &version,
	      const Gtk::string &copyright,
	      const Gtk::SArray &authors,
	      const Gtk::string &comments = "",
	      const Gtk::nstring &logo = 0);




  // Has no nonstandard methods; use Gnome_Dialog methods.

public:

protected:
  // impl functions

};

}

#endif
