// -*- c++ -*-
//  Generated by gtkmmproc from ./../dateedit.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DATEEDIT_P_H
#define _GNOMEMM_DATEEDIT_P_H
#include <gtk--/private/box_p.h>
namespace Gnome
{
class DateEdit_Class
{
public:

  typedef DateEdit           CppObjectType;
  typedef GnomeDateEdit           BaseObjectType;
  typedef GnomeDateEditClass      BaseClassType;
  typedef Gtk::HBox_Class     CppClassParent;
  typedef GtkHBoxClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void date_changed_callback(GnomeDateEdit* o_);
  static void time_changed_callback(GnomeDateEdit* o_);
  // Data
  GtkType type;
};

}
#endif
