// -*- c++ -*-
//  Generated by gtkmmproc from ./../canvas-rect-ellipse.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CANVAS_RECT_ELLIPSE_H
#define _GNOMEMM_CANVAS_RECT_ELLIPSE_H

// -*- C++ -*-
/* $Id: canvas-rect-ellipse.gen_h,v 1.14 2001/06/22 17:58:30 murrayc Exp $ */

/* canvas-ellipse.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gnome--/canvas-item.h>
//#include <gnome--/canvas-group.h>
#include <libgnomeui/gnome-canvas-rect-ellipse.h>

namespace Gnome {
class CanvasRE;
class CanvasRE_Class;
}
namespace Gtk { Gnome::CanvasRE *wrap (GnomeCanvasRE *o); }
namespace Gnome
{

// Abstract class for all rectangular shapes
class CanvasRE : public CanvasItem
{

public:
  typedef CanvasRE          CppObjectType;
  typedef CanvasRE_Class    CppClassType;
  typedef GnomeCanvasRE           BaseObjectType;
  typedef GnomeCanvasREClass      BaseClassType;

private:
  friend class CanvasRE_Class;
  static CppClassType canvas_re_class;

  CanvasRE(const CanvasRE&);
  CanvasRE& operator=(const CanvasRE&); // not implemented

protected:
  void   initialize_class();
  explicit CanvasRE(GnomeCanvasRE *castitem);

public:
  static GtkType get_type();
  GnomeCanvasRE* gtkobj()             { return (GnomeCanvasRE*)(gtkobject); }
  const GnomeCanvasRE* gtkobj() const { return (GnomeCanvasRE*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~CanvasRE();

private:

public:
  CanvasRE(const CanvasGroup &parent,
		      const gchar *first_arg_name,
		      ...);
  CanvasRE(const CanvasGroup &parent);



  void set_x1(gdouble);
  gdouble get_x1() const;

  void set_x2(gdouble);
  gdouble get_x2() const;

  void set_y1(gdouble);
  gdouble get_y1() const;

  void set_y2(gdouble);
  gdouble get_y2() const;
  void set_width_pixels(guint);
  void set_width_units(gdouble);

  void set_fill_color(const Gtk::string&);
  void set_fill_color(const Gdk_Color&);
  Gdk_Color get_fill_color() const;

  //FIXME: fill_color_rgba?
  void set_fill_stipple(const Gdk_Pixmap&);
  Gdk_Pixmap get_fill_stipple() const;
  void set_outline_color(const Gtk::string&);
  void set_outline_color(const Gdk_Color&);
  Gdk_Color get_outline_color() const;

  void set_outline_stipple(const Gdk_Pixmap&);
  Gdk_Pixmap get_outline_stipple() const;

public:

protected:
  // impl functions

};

}

#endif
