// -*- c++ -*-
//  Generated by gtkmmproc from ./../main.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_MAIN_H
#define _GNOMEMM_MAIN_H

/* $Id: main.gen_h,v 1.19 2000/10/07 18:15:21 kenelson Exp $ */
// -*- C++ -*- // this is for the .gen_h, I realize gensig puts one in

/* main.h
 *
 * Copyright (C) 1998 EMC Capital Management Inc.
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/main.h>
#include <libgnomeui/libgnomeui.h>


namespace Gnome
{
class Main : public Gtk::Main
{
public:

  Main(const Gtk::string &app_id, const Gtk::string &app_version,
	     int argc, gchar **argv);

  Main(const Gtk::string &app_id,
	     const Gtk::string &app_version,
	     int argc, gchar **argv,
	     const struct poptOption *options,
	     int flags,
	     poptContext *return_ctx);

  ~Main();

protected:
  Main();
  static char *app_id_,*app_version_;
  void ids(const Gtk::string& app_id,const Gtk::string& app_version);
  void init_gnomemm_internals();
};

}

#endif
