// -*- c++ -*-
//  Generated by gtkmmproc from ./../mdi-child.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_MDI_CHILD_P_H
#define _GNOMEMM_MDI_CHILD_P_H
#include <gtk--/private/object_p.h>
namespace Gnome
{
class MDIChild_Class
{
public:

  typedef MDIChild           CppObjectType;
  typedef GnomeMDIChild           BaseObjectType;
  typedef GnomeMDIChildClass      BaseClassType;
  typedef Gtk::Object_Class     CppClassParent;
  typedef GtkObjectClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static GtkWidget* create_view(GnomeMDIChild* child , gpointer data);
  static gchar*     get_config_string(GnomeMDIChild* child, gpointer data);
  static GtkWidget* set_label(GnomeMDIChild* child, GtkWidget* label , gpointer data);
  // Data
  GtkType type;
};

}
#endif
