// -*- c++ -*-
//  Generated by gtkmmproc from ./../paper-selector.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_PAPER_SELECTOR_H
#define _GNOMEMM_PAPER_SELECTOR_H

/* $Id: paper-selector.gen_h,v 1.5 2000/08/29 18:09:02 kenelson Exp $ */


/* paper-selector.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/box.h>
#include <libgnomeui/gnome-paper-selector.h>

namespace Gnome {
class PaperSelector;
class PaperSelector_Class;
}
namespace Gtk { Gnome::PaperSelector *wrap (GnomePaperSelector *o); }
namespace Gnome
{
class PaperSelector : public Gtk::VBox
{

public:
  typedef PaperSelector          CppObjectType;
  typedef PaperSelector_Class    CppClassType;
  typedef GnomePaperSelector           BaseObjectType;
  typedef GnomePaperSelectorClass      BaseClassType;

private:
  friend class PaperSelector_Class;
  static CppClassType paper_selector_class;

  PaperSelector(const PaperSelector&);
  PaperSelector& operator=(const PaperSelector&); // not implemented

protected:
  void   initialize_class();
  explicit PaperSelector(GnomePaperSelector *castitem);

public:
  static GtkType get_type();
  GnomePaperSelector* gtkobj()             { return (GnomePaperSelector*)(gtkobject); }
  const GnomePaperSelector* gtkobj() const { return (GnomePaperSelector*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~PaperSelector();

private:

public:
  PaperSelector();




  Gtk::string get_name();


  gfloat get_width();


  gfloat get_height();


  gfloat get_left_margin();


  gfloat get_right_margin();


  gfloat get_top_margin();


  gfloat get_bottom_margin();


  void set_name(const Gtk::string& name);


  void set_width(gfloat width);


  void set_height(gfloat height);

public:

protected:
  // impl functions

};



}

#endif
