// -*- c++ -*-
//  Generated by gtkmmproc from ./../client.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_CLIENT_P_H
#define _GNOMEMM_CLIENT_P_H
#include <gtk--/private/object_p.h>
namespace Gnome
{
class Client_Class
{
public:

  typedef Client           CppObjectType;
  typedef GnomeClient           BaseObjectType;
  typedef GnomeClientClass      BaseClassType;
  typedef Gtk::Object_Class     CppClassParent;
  typedef GtkObjectClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static gint save_yourself_callback(GnomeClient* o_,gint p0,GnomeSaveStyle p1,gint p2,GnomeInteractStyle p3,gint p4);
  static void die_callback(GnomeClient* o_);
  static void save_complete_callback(GnomeClient* o_);
  static void shutdown_cancelled_callback(GnomeClient* o_);
  static void connect_callback(GnomeClient* o_,gint p0);
  static void disconnect_callback(GnomeClient* o_);
  // Data
  GtkType type;
};

}
#endif
