// -*- c++ -*-
//  Generated by gtkmmproc from ./../icon-list.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_ICON_LIST_P_H
#define _GNOMEMM_ICON_LIST_P_H
#include <gnome--/private/canvas_p.h>
namespace Gnome
{
class IconList_Class
{
public:

  typedef IconList           CppObjectType;
  typedef GnomeIconList           BaseObjectType;
  typedef GnomeIconListClass      BaseClassType;
  typedef Canvas_Class     CppClassParent;
  typedef GnomeCanvasClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void select_icon_callback(GnomeIconList* o_,gint p0,GdkEvent* p1);
  static void unselect_icon_callback(GnomeIconList* o_,gint p0,GdkEvent* p1);
  static gboolean text_changed_callback(GnomeIconList* o_,gint p0,const gchar* p1);
  // Data
  GtkType type;
};

}
#endif
