// -*- c++ -*-
//  Generated by gtkmmproc from ./../entry.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_ENTRY_H
#define _GNOMEMM_ENTRY_H

/* $Id: entry.gen_h,v 1.4 2000/08/29 18:09:02 kenelson Exp $ */


/* entry.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/combo.h>
#include <libgnomeui/gnome-entry.h>

namespace Gnome {
class Entry;
class Entry_Class;
}
namespace Gtk { Gnome::Entry *wrap (GnomeEntry *o); }
namespace Gnome
{
class Entry : public Gtk::Combo
{

public:
  typedef Entry          CppObjectType;
  typedef Entry_Class    CppClassType;
  typedef GnomeEntry           BaseObjectType;
  typedef GnomeEntryClass      BaseClassType;

private:
  friend class Entry_Class;
  static CppClassType entry_class;

  Entry(const Entry&);
  Entry& operator=(const Entry&); // not implemented

protected:
  void   initialize_class();
  explicit Entry(GnomeEntry *castitem);

public:
  static GtkType get_type();
  GnomeEntry* gtkobj()             { return (GnomeEntry*)(gtkobject); }
  const GnomeEntry* gtkobj() const { return (GnomeEntry*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~Entry();

private:

public:
  Entry();



  Gtk::Widget* gtk_entry();


  void set_history_id(const Gtk::string& history_id);


  void set_max_saved(guint max_saved);


  void prepend_history(gint save,const Gtk::string& text);


  void append_history(gint save,const Gtk::string& text);


  void load_history();


  void save_history();

public:

protected:
  // impl functions

};



}


#endif
