// -*- c++ -*-
//  Generated by gtkmmproc from ./../font-picker.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_FONT_PICKER_P_H
#define _GNOMEMM_FONT_PICKER_P_H
#include <gtk--/private/button_p.h>
namespace Gnome
{
class FontPicker_Class
{
public:

  typedef FontPicker           CppObjectType;
  typedef GnomeFontPicker           BaseObjectType;
  typedef GnomeFontPickerClass      BaseClassType;
  typedef Gtk::Button_Class     CppClassParent;
  typedef GtkButtonClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static void font_set_callback(GnomeFontPicker* o_,gchar* p0);
  // Data
  GtkType type;
};

}
#endif
