// -*- c++ -*-
//  Generated by gtkmmproc from ./../druid-page.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_DRUID_PAGE_P_H
#define _GNOMEMM_DRUID_PAGE_P_H
#include <gtk--/private/bin_p.h>
namespace Gnome
{
class DruidPage_Class
{
public:

  typedef DruidPage           CppObjectType;
  typedef GnomeDruidPage           BaseObjectType;
  typedef GnomeDruidPageClass      BaseClassType;
  typedef Gtk::Bin_Class     CppClassParent;
  typedef GtkBinClass      BaseClassParent;


  static void class_init_function(BaseClassType *p);
  static void object_init_function(BaseObjectType *o);
  GtkType get_type();

  // Hook for translating API
  static Gtk::Object* wrap_new(GtkObject*);

  // Callbacks here...

  static gboolean next_callback(GnomeDruidPage *, GtkWidget *);
  static void prepare_callback(GnomeDruidPage *, GtkWidget *);
  static gboolean back_callback(GnomeDruidPage *, GtkWidget *);
  static void finish_callback(GnomeDruidPage *, GtkWidget *);
  static gboolean cancel_callback(GnomeDruidPage *, GtkWidget *);
  // Data
  GtkType type;
};

}
#endif
