// -*- c++ -*-
//  Generated by gtkmmproc from ./../href.gen_h -- DO NOT MODIFY!
#ifndef _GNOMEMM_HREF_H
#define _GNOMEMM_HREF_H

/* $Id: href.gen_h,v 1.2 2000/08/31 15:46:25 kenelson Exp $ */


/* href.gen_h
 *
 * Copyright (C) 1999 The Gtk-- Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk--/button.h>
#include <libgnomeui/gnome-href.h>

namespace Gnome {
class HRef;
class HRef_Class;
}
namespace Gtk { Gnome::HRef *wrap (GnomeHRef *o); }
namespace Gnome
{
class HRef : public Gtk::Button
{

public:
  typedef HRef          CppObjectType;
  typedef HRef_Class    CppClassType;
  typedef GnomeHRef           BaseObjectType;
  typedef GnomeHRefClass      BaseClassType;

private:
  friend class HRef_Class;
  static CppClassType href_class;

  HRef(const HRef&);
  HRef& operator=(const HRef&); // not implemented

protected:
  void   initialize_class();
  explicit HRef(GnomeHRef *castitem);

public:
  static GtkType get_type();
  GnomeHRef* gtkobj()             { return (GnomeHRef*)(gtkobject); }
  const GnomeHRef* gtkobj() const { return (GnomeHRef*)(gtkobject); }
  static bool isA(Gtk::Object *checkcast);

  // Hook for proxies
  static const char* const signal_names[];

  virtual ~HRef();

private:

public:
  HRef(const Gtk::string &url, const Gtk::string &label);
  HRef(const Gtk::string &url);




  void set_url(const Gtk::string& url);


  Gtk::string get_url();


  void set_label(const Gtk::string& label);


  Gtk::string get_label();

public:

protected:
  // impl functions

};



}


#endif
